#include "USB.h"
#include "USBMIDI.h"
USBMIDI MIDI;

const int buttonPins[] = { 0, 4, 5, 6, 7, 8, 18 };
int butState[] = { 0, 0, 0, 0, 0, 0, 0 };
int prevState[] = { 0, 0, 0, 0, 0, 0, 0 };
int notes[] = { 50, 52, 54, 56, 58, 60, 62 };

// Define pins for the potentiometers
const int potPins[] = { A9, A2, A1 };
int potValues[] = { 0, 0, 0 };
int prevPotValues[] = { 0, 0, 0 };
const int midiCC[] = { 1, 2, 3 }; // MIDI Control Change numbers for the potentiometers

void setup() {
  MIDI.begin();
  USB.begin();
  for (int i = 0; i < 7; i++) {
    pinMode(buttonPins[i], INPUT_PULLUP);
  }
  for (int i = 0; i < 7; i++) {
    butState[i] = digitalRead(buttonPins[i]);
  }
  for (int i = 0; i < 7; i++) {
    prevState[i] = digitalRead(buttonPins[i]);
  }
}

void loop() {
  // Read button states and send note on/off messages
  for (int i = 0; i < 7; i++) {
    butState[i] = digitalRead(buttonPins[i]);
    if (butState[i] != prevState[i]) {
      prevState[i] = butState[i];
      if (butState[i] == 1) {
        MIDI.noteOff(notes[i], 0);
      } else {
        MIDI.noteOn(notes[i], 126);
      }
    }
  }

  // Read potentiometer values and send MIDI CC messages
  for (int i = 0; i < 3; i++) {
    potValues[i] = analogRead(potPins[i]) / 8; // Scale 10-bit ADC value (0-1023) to 7-bit MIDI value (0-127)
    if (potValues[i] != prevPotValues[i]) {
      prevPotValues[i] = potValues[i];
      MIDI.controlChange(midiCC[i], potValues[i], 1);
    }
  }

  delay(100);
}
